const { DataTypes } = require('sequelize');
const sequelize = require('../config/database');

const Node = sequelize.define('Node', {
  id: {
    type: DataTypes.INTEGER,
    primaryKey: true,
    autoIncrement: true
  },
  name: {
    type: DataTypes.STRING(255),
    allowNull: false,
    comment: '节点名称'
  },
  type: {
    type: DataTypes.STRING(50),
    allowNull: false,
    comment: '节点类型 (ss, ssr, vmess, trojan等)'
  },
  server: {
    type: DataTypes.STRING(255),
    allowNull: false,
    comment: '服务器地址'
  },
  port: {
    type: DataTypes.INTEGER,
    allowNull: false,
    comment: '端口号'
  },
  password: {
    type: DataTypes.STRING(255),
    allowNull: true,
    comment: '密码'
  },
  method: {
    type: DataTypes.STRING(50),
    allowNull: true,
    comment: '加密方法'
  },
  uuid: {
    type: DataTypes.STRING(255),
    allowNull: true,
    comment: 'UUID (vmess使用)'
  },
  alterId: {
    type: DataTypes.INTEGER,
    allowNull: true,
    comment: 'Alter ID (vmess使用)'
  },
  network: {
    type: DataTypes.STRING(20),
    allowNull: true,
    defaultValue: 'tcp',
    comment: '网络类型 (tcp, ws, http等)'
  },
  wsPath: {
    type: DataTypes.STRING(255),
    allowNull: true,
    comment: 'WebSocket路径'
  },
  wsHeaders: {
    type: DataTypes.TEXT,
    allowNull: true,
    comment: 'WebSocket请求头 (JSON格式)'
  },
  tls: {
    type: DataTypes.BOOLEAN,
    allowNull: true,
    defaultValue: false,
    comment: '是否启用TLS'
  },
  sni: {
    type: DataTypes.STRING(255),
    allowNull: true,
    comment: 'SNI域名'
  },
  group: {
    type: DataTypes.STRING(100),
    allowNull: true,
    comment: '节点分组'
  },
  isActive: {
    type: DataTypes.BOOLEAN,
    allowNull: false,
    defaultValue: true,
    comment: '是否启用'
  },
  lastTestTime: {
    type: DataTypes.DATE,
    allowNull: true,
    comment: '最后测试时间'
  },
  lastTestResult: {
    type: DataTypes.BOOLEAN,
    allowNull: true,
    comment: '最后测试结果'
  },
  averageLatency: {
    type: DataTypes.INTEGER,
    allowNull: true,
    comment: '平均延迟 (毫秒)'
  },
  averageSpeed: {
    type: DataTypes.FLOAT,
    allowNull: true,
    comment: '平均速度 (Mbps)'
  },
  failureCount: {
    type: DataTypes.INTEGER,
    allowNull: false,
    defaultValue: 0,
    comment: '连续失败次数'
  },
  status: {
    type: DataTypes.ENUM('online', 'offline', 'testing'),
    allowNull: false,
    defaultValue: 'offline',
    comment: '节点状态'
  },
  subscriptionId: {
    type: DataTypes.INTEGER,
    allowNull: true,
    comment: '所属订阅ID'
  }
}, {
  tableName: 'nodes',
  timestamps: true,
  indexes: [
    {
      fields: ['group']
    },
    {
      fields: ['status']
    },
    {
      fields: ['isActive']
    },
    {
      fields: ['subscriptionId']
    }
  ]
});

module.exports = Node; 