const { DataTypes } = require('sequelize');
const sequelize = require('../config/database');

const Notification = sequelize.define('Notification', {
  id: {
    type: DataTypes.INTEGER,
    primaryKey: true,
    autoIncrement: true
  },
  nodeId: {
    type: DataTypes.INTEGER,
    allowNull: true,
    comment: '节点ID (可选，系统通知为null)'
  },
  type: {
    type: DataTypes.ENUM('failure', 'recovery', 'system', 'summary', 'subscription'),
    allowNull: false,
    comment: '通知类型'
  },
  title: {
    type: DataTypes.STRING(255),
    allowNull: false,
    comment: '通知标题'
  },
  message: {
    type: DataTypes.TEXT,
    allowNull: false,
    comment: '通知内容'
  },
  platform: {
    type: DataTypes.STRING(50),
    allowNull: false,
    defaultValue: 'telegram',
    comment: '通知平台'
  },
  isSent: {
    type: DataTypes.BOOLEAN,
    allowNull: false,
    defaultValue: false,
    comment: '是否已发送'
  },
  sentTime: {
    type: DataTypes.DATE,
    allowNull: true,
    comment: '发送时间'
  },
  retryCount: {
    type: DataTypes.INTEGER,
    allowNull: false,
    defaultValue: 0,
    comment: '重试次数'
  },
  errorMessage: {
    type: DataTypes.TEXT,
    allowNull: true,
    comment: '发送错误信息'
  },
  metadata: {
    type: DataTypes.TEXT,
    allowNull: true,
    comment: '额外数据 (JSON格式)'
  }
}, {
  tableName: 'notifications',
  timestamps: true,
  indexes: [
    {
      fields: ['nodeId']
    },
    {
      fields: ['type']
    },
    {
      fields: ['isSent']
    },
    {
      fields: ['createdAt']
    }
  ]
});

module.exports = Notification; 