const { DataTypes } = require('sequelize');
const sequelize = require('../config/database');

const Subscription = sequelize.define('Subscription', {
  id: {
    type: DataTypes.INTEGER,
    primaryKey: true,
    autoIncrement: true
  },
  name: {
    type: DataTypes.STRING(100),
    allowNull: false,
    comment: '订阅名称'
  },
  url: {
    type: DataTypes.STRING(500),
    allowNull: false,
    comment: '订阅链接'
  },
  description: {
    type: DataTypes.TEXT,
    allowNull: true,
    comment: '订阅描述'
  },
  speedTestConfig: {
    type: DataTypes.JSON,
    allowNull: true,
    defaultValue: {
      testCount: 3,
      timeout: 10000,
      testUrls: ['https://www.google.com', 'https://www.youtube.com'],
      speedTestEnabled: true
    },
    comment: '测速配置'
  },
  notifyConfig: {
    type: DataTypes.JSON,
    allowNull: true,
    defaultValue: {
      enabled: true,
      notifyOnSpeedTest: true,
      notifyOnNodeUpdate: true,
      webhookUrl: '',
      emailConfig: null
    },
    comment: '通知配置'
  },
  isActive: {
    type: DataTypes.BOOLEAN,
    allowNull: false,
    defaultValue: true,
    comment: '是否启用'
  },
  lastUpdateTime: {
    type: DataTypes.DATE,
    allowNull: true,
    comment: '最后更新时间'
  },
  nodeCount: {
    type: DataTypes.INTEGER,
    allowNull: false,
    defaultValue: 0,
    comment: '节点数量'
  }
}, {
  tableName: 'subscriptions',
  timestamps: true,
  indexes: [
    {
      fields: ['isActive']
    },
    {
      fields: ['name']
    }
  ]
});

module.exports = Subscription; 