const { DataTypes } = require('sequelize');
const sequelize = require('../config/database');

const TestResult = sequelize.define('TestResult', {
  id: {
    type: DataTypes.INTEGER,
    primaryKey: true,
    autoIncrement: true
  },
  nodeId: {
    type: DataTypes.INTEGER,
    allowNull: false,
    comment: '节点ID'
  },
  testTime: {
    type: DataTypes.DATE,
    allowNull: false,
    defaultValue: DataTypes.NOW,
    comment: '测试时间'
  },
  isSuccess: {
    type: DataTypes.BOOLEAN,
    allowNull: false,
    comment: '测试是否成功'
  },
  latency: {
    type: DataTypes.INTEGER,
    allowNull: true,
    comment: '延迟 (毫秒)'
  },
  downloadSpeed: {
    type: DataTypes.FLOAT,
    allowNull: true,
    comment: '下载速度 (Mbps)'
  },
  uploadSpeed: {
    type: DataTypes.FLOAT,
    allowNull: true,
    comment: '上传速度 (Mbps)'
  },
  packetLoss: {
    type: DataTypes.FLOAT,
    allowNull: true,
    comment: '丢包率 (%)'
  },
  testUrl: {
    type: DataTypes.STRING(255),
    allowNull: true,
    comment: '测试URL'
  },
  errorMessage: {
    type: DataTypes.TEXT,
    allowNull: true,
    comment: '错误信息'
  },
  testDuration: {
    type: DataTypes.INTEGER,
    allowNull: true,
    comment: '测试持续时间 (毫秒)'
  },
  ipAddress: {
    type: DataTypes.STRING(45),
    allowNull: true,
    comment: '节点IP地址'
  },
  location: {
    type: DataTypes.STRING(100),
    allowNull: true,
    comment: '节点位置'
  }
}, {
  tableName: 'test_results',
  timestamps: true,
  indexes: [
    {
      fields: ['nodeId']
    },
    {
      fields: ['testTime']
    },
    {
      fields: ['isSuccess']
    }
  ]
});

module.exports = TestResult; 